.. SPDX-FileCopyrightText: 2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

Introduction
============

``oc_ocdm`` is a Python >3.7 library that enables the user to import, produce, modify and export RDF data
structures which are compliant with the `OCDM v2.0.1 <https://figshare.com/articles/Metadata_for_the_OpenCitations_Corpus/3443876>`_
specification.

.. note::
   Other OpenCitations projects that make use of this library are, for example:

     * **WCW** (Wikipedia Citations in Wikidata): https://github.com/opencitations/wcw
     * **meta**: https://github.com/opencitations/meta
     * **oc_graphenricher**: https://github.com/opencitations/oc_graphenricher

Installing
----------
This package can be simply installed with **pip**:

.. code-block:: bash

    pip install oc_ocdm

License
-------
Distributed under the ISC License. See :doc:`license` for more information.

Contacts
--------
Project authors/contributors:

  * Silvio Peroni <essepuntato@gmail.com>
  * Marilena Daquino <marilena.daquino2@unibo.it>
  * Fabio Mariani <fabio.mariani6@studio.unibo.it>
  * Simone Persiani <iosonopersia@gmail.com>

Useful links
------------

  * GitHub repository: https://github.com/opencitations/oc_ocdm
  * PyPi repository: https://pypi.org/project/oc-ocdm
  * Zenodo repository: https://doi.org/10.5281/zenodo.5770646
  * ReadTheDocks documentation: https://oc-ocdm.readthedocs.io/

Acknowledgements
----------------
This work has been funded by the project “Open Biomedical Citations in Context Corpus”
(Wellcome Trust, Grant n. 214471/Z/18/Z) and the project “Wikipedia Citations in Wikidata”
(Wikimedia Foundation, https://meta.wikimedia.org/wiki/Wikicite/grant/Wikipedia_Citations_in_Wikidata).

We would like to thank (in alphabetic order) `Fabio Mariani <https://github.com/FabioMariani>`_, `Arcangelo
Massari <https://github.com/arcangelo7>`_, and `Gabriele Pisciotta <https://github.com/GabrielePisciotta>`_ for the constructive feedback.
